<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\AccompanyingPeriod\Workflow;

use Chill\MainBundle\Entity\Notification;
use Chill\MainBundle\Entity\User;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Security\Core\Security;
use Symfony\Component\Templating\EngineInterface;
use Symfony\Component\Workflow\Event\EnteredEvent;
use Symfony\Contracts\Translation\TranslatorInterface;

class WorkflowEventSubscriber implements EventSubscriberInterface
{
    private EntityManagerInterface $em;

    private EngineInterface $engine;

    private Security $security;

    private TranslatorInterface $translator;

    public function __construct(Security $security, TranslatorInterface $translator, EngineInterface $engine, EntityManagerInterface $em)
    {
        $this->security = $security;
        $this->translator = $translator;
        $this->engine = $engine;
        $this->em = $em;
    }

    public static function getSubscribedEvents()
    {
        return [
            'workflow.accompanying_period_lifecycle.entered' => [
                'onStateEntered',
            ],
        ];
    }

    public function onStateEntered(EnteredEvent $enteredEvent): void
    {
        if ($enteredEvent->getMarking()->has(AccompanyingPeriod::STEP_CONFIRMED)) {
            $this->onPeriodConfirmed($enteredEvent->getSubject());
        }
    }

    private function onPeriodConfirmed(AccompanyingPeriod $period)
    {
        if ($period->getUser() instanceof User
            && $period->getUser() !== $this->security->getUser()) {
            $notification = new Notification();
            $notification
                ->setRelatedEntityId($period->getId())
                ->setRelatedEntityClass(AccompanyingPeriod::class)
                ->setTitle($this->translator->trans('period_notification.period_designated_subject'))
                ->setMessage($this->engine->render(
                    '@ChillPerson/Notification/accompanying_course_designation.md.twig',
                    [
                        'accompanyingCourse' => $period,
                    ]
                ))
                ->addAddressee($period->getUser());
            $this->em->persist($notification);
        }
    }
}
